@@ -113,11 +113,20 @@ ews_notification_authenticate (SoupSession *session,
 EEwsNotification *
 e_ews_notification_new (EEwsConnection *connection)
 {
+	EEwsNotification *notification;
+	CamelEwsSettings *ews_settings;
+
 	g_return_val_if_fail (E_IS_EWS_CONNECTION (connection), NULL);
 
-	return g_object_new (
+	notification = g_object_new (
 		E_TYPE_EWS_NOTIFICATION,
 		"connection", connection, NULL);
+
+	ews_settings = e_ews_connection_ref_settings (connection);
+
+	g_object_unref (ews_settings);
+
+	return notification;
 }
 
 static void
@@ -139,7 +148,7 @@ static EEwsConnection *
 e_ews_notification_get_connection (const EEwsNotification *notification)
 {
 	g_return_val_if_fail (E_IS_EWS_NOTIFICATION (notification), NULL);
-	g_return_val_if_fail (notification->priv != NULL, NULL);
+	g_return_val_if_fail (notification->priv == NULL, NULL);
 
 	return notification->priv->connection;
 }
@@ -306,6 +315,7 @@ e_ews_notification_subscribe_folder_sync (EEwsNotification *notification,
 	GSList *l;
 	guint event_type;
 	xmlDoc *doc;
+	gint log_level = e_ews_debug_get_log_level ();
 
 	g_return_val_if_fail (notification != NULL, FALSE);
 	g_return_val_if_fail (notification->priv != NULL, FALSE);
@@ -369,6 +379,10 @@ e_ews_notification_subscribe_folder_sync (EEwsNotification *notification,
 		return FALSE;
 	}
 
+	if (log_level >= 1 && log_level < 3) {
+		e_ews_debug_dump_raw_soup_request (SOUP_MESSAGE (msg));
+	}
+
 	soup_session_send_message (notification->priv->soup_session, SOUP_MESSAGE (msg));
 	if (!SOUP_STATUS_IS_SUCCESSFUL (SOUP_MESSAGE (msg)->status_code)) {
 		g_object_unref (msg);
@@ -383,6 +397,10 @@ e_ews_notification_subscribe_folder_sync (EEwsNotification *notification,
 	response = e_soap_response_new_from_xmldoc (doc);
 	g_object_unref (msg);
 
+	if (log_level >= 1 && log_level < 3) {
+		e_ews_debug_dump_raw_soup_response (SOUP_MESSAGE (msg));
+	}
+
 	param = e_soap_response_get_first_parameter_by_name (response, "ResponseMessages", &error);
 
 	/* Sanity check */
@@ -643,6 +661,7 @@ ews_notification_soup_got_chunk (SoupMessage *msg,
 	const gchar *chunk_str;
 	gsize chunk_len;
 	gboolean keep_parsing = TRUE;
+	gint log_level = e_ews_debug_get_log_level ();
 
 	/*
 	 * Here we receive, in chunks, "well-formed" messages that contain:
@@ -686,6 +705,11 @@ ews_notification_soup_got_chunk (SoupMessage *msg,
 		if (response == NULL)
 			break;
 
+		if (log_level >= 1 && log_level < 3) {
+			e_ews_debug_dump_raw_soup_response (msg);
+			e_soap_response_dump_response (response, stdout);
+		}
+
 		if (!ews_notification_fire_events_from_response (notification, response)) {
 			soup_session_abort (notification->priv->soup_session);
 
@@ -765,13 +789,6 @@ e_ews_notification_get_events_sync (EEwsNotification *notification,
 	return ret;
 }
 
-static void
-ews_notification_cancelled_cb (GCancellable *cancellable,
-			       SoupSession *session)
-{
-	soup_session_abort (session);
-}
-
 static gpointer
 e_ews_notification_get_events_thread (gpointer user_data)
 {
@@ -787,22 +804,14 @@ e_ews_notification_get_events_thread (gpointer user_data)
 		goto exit;
 
 	do {
-		gulong handler_id;
-
 		if (g_cancellable_is_cancelled (td->cancellable))
 			goto exit;
 
-		handler_id = g_cancellable_connect (td->cancellable, G_CALLBACK (ews_notification_cancelled_cb),
-			g_object_ref (td->notification->priv->soup_session), g_object_unref);
-
 		ret = e_ews_notification_get_events_sync (
 				td->notification,
 				subscription_id);
 
-		if (handler_id > 0)
-			g_cancellable_disconnect (td->cancellable, handler_id);
-
-		if (!ret && !g_cancellable_is_cancelled (td->cancellable)) {
+		if (!ret) {
 			g_debug ("%s: Failed to get notification events (SubscriptionId: '%s')", G_STRFUNC, subscription_id);
 
 			e_ews_notification_unsubscribe_folder_sync (td->notification, subscription_id);
